4Suite API Documentation: Ft.Lib.Terminfo

4Suite™ API Documentation

# ► Module Ft.Lib.Terminfo

Provides some of the information from the terminfo database.

    Copyright 2005 Fourthought, Inc. (USA).
    Detailed license and copyright information: http://4suite.org/COPYRIGHT
    Project home, documentation, distributions: http://4suite.org/

Functions: GetColumns, GetLines |  |  |  | Globals: DEFAULT_COLUMNS, DEFAULT_LINES, TERMTYPES

## Functions

GetColumns(stream=<open file '<stdout>', mode 'w' at 0xb7d98068>)
GetLines(stream=<open file '<stdout>', mode 'w' at 0xb7d98068>)

## Globals

DEFAULT_COLUMNS = 80
DEFAULT_LINES = 24
TERMTYPES = ['linux', 'console', 'con132x25', 'con132x30', 'con132x43', 'con132x60', 'con80x25', 'con80x28', 'con80x30', 'con80x43', 'con80x50', 'con80x60', 'xterm', 'xterm-color', 'color-xterm', 'vt100', 'vt100-color', 'rxvt', 'ansi', 'Eterm', ...]